# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-06 12:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0034_auto_20170921_1535'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='sample',
            field=models.BooleanField(default=False, help_text='If this option is checked the product can not be sold', verbose_name='Sample'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 10:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0012_auto_20170505_0828'),
    ]

    operations = [
        migrations.CreateModel(
            name='OptionValueAttributeTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueAttribute')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttributeTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueAttribute')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeatureSpecial')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecialTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeatureSpecial')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.OptionValueFeature')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('option_value', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.OptionValueFeature')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-01 10:56
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0030_productfinaloption_productfinaloptiontexten_productfinaloptiontextes'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='product',
            name='recargo_equivalencia',
        ),
        migrations.AddField(
            model_name='productfinal',
            name='price_base',
            field=models.FloatField(default=0, editable=False, verbose_name='Price base'),
        ),
        migrations.AddField(
            model_name='typetax',
            name='recargo_equivalencia',
            field=models.FloatField(default=0, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Recargo de equivalencia (%)'),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-02 12:01
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0024_auto_20170802_0955'),
    ]

    operations = [
        migrations.CreateModel(
            name='PackImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('pack', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs_image', to='codenerix_products.Pack', verbose_name='Pack')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('pack_image', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.PackImage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('pack_image', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.PackImage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='productimagecreate',
            name='temporal_A',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimagecreatemodal',
            name='temporal_B',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimageupdate',
            name='temporal_C',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimageupdatemodal',
            name='temporal_D',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.RemoveField(
            model_name='productimagecreatemodal',
            name='productimagecreate_ptr',
        ),
        migrations.RemoveField(
            model_name='productimageupdatemodal',
            name='productimageupdate_ptr',
        ),
        migrations.RemoveField(
            model_name='productimagecreate',
            name='productimage_ptr',
        ),
        migrations.RemoveField(
            model_name='productimageupdate',
            name='productimage_ptr',
        ),
        migrations.DeleteModel(
            name='ProductImageCreate',
        ),
        migrations.DeleteModel(
            name='ProductImageCreateModal',
        ),
        migrations.DeleteModel(
            name='ProductImageUpdate',
        ),
        migrations.DeleteModel(
            name='ProductImageUpdateModal',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-19 11:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0008_category_order'),
    ]

    operations = [
        migrations.AddField(
            model_name='brand',
            name='show_menu',
            field=models.BooleanField(default=True, verbose_name='Show menu'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-10-19 11:10
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0037_auto_20171018_1007'),
    ]

    operations = [
        migrations.AddField(
            model_name='family',
            name='icon',
            field=codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-12 09:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0007_productfinalimage_productfinalimagetexten_productfinalimagetextes'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='order',
            field=models.SmallIntegerField(blank=True, null=True, verbose_name='Order'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-23 09:40
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0019_productfinal_ean13'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='recargo_equivalencia',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products', to='codenerix_products.TypeRecargoEquivalencia', verbose_name='Recargo Equivalencia (%)'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 14:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0026_packoption_order'),
    ]

    operations = [
        migrations.AddField(
            model_name='pack',
            name='order',
            field=models.SmallIntegerField(blank=True, null=True, verbose_name='Order'),
        ),
        migrations.AddField(
            model_name='pack',
            name='tax',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.TypeTax', verbose_name='Tax'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 08:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0010_auto_20170428_0850'),
    ]

    operations = [
        migrations.CreateModel(
            name='GroupValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GroupValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Name')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueAttribute',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_attribute', to='codenerix_products.GroupValueAttribute', verbose_name='Options value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature', to='codenerix_products.GroupValueFeature', verbose_name='Options value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValueFeatureSpecial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options_value_feature_special', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='Options value')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OptionValues',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 13:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0033_auto_20170921_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='brandtexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='brandtextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='productfinaltexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='productfinaltextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='producttexttexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='producttexttextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-28 14:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0004_auto_20170307_1045'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='product',
            name='name',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-01 17:19
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0022_typetax_default'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pack',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('price', models.FloatField(verbose_name='Price')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Category', verbose_name='Category')),
                ('family', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Family', verbose_name='Family')),
                ('subcategory', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Subcategory', verbose_name='Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('pack', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pack_options', to='codenerix_products.Pack', verbose_name='Pack Option')),
                ('products', models.ManyToManyField(related_name='pack_options', to='codenerix_products.ProductFinal')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOptionTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('packoption', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.PackOption')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOptionTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('packoption', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.PackOption')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('pack', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Pack')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('pack', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Pack')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-03 13:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0038_family_icon'),
    ]

    operations = [
        migrations.AlterField(
            model_name='categorytexten',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='categorytextes',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='familytexten',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='familytextes',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='productfinaloptiontexten',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='productfinaloptiontextes',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='subcategorytexten',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='subcategorytextes',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-10 14:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0018_auto_20170508_0911'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='ean13',
            field=models.CharField(blank=True, max_length=13, null=True, verbose_name='EAN-13'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 15:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0028_auto_20170803_1446'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pack',
            name='category',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='family',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='subcategory',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='packimage',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packimagetexten',
            name='pack_image',
        ),
        migrations.RemoveField(
            model_name='packimagetextes',
            name='pack_image',
        ),
        migrations.RemoveField(
            model_name='packoption',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packoption',
            name='products',
        ),
        migrations.RemoveField(
            model_name='packoptiontexten',
            name='packoption',
        ),
        migrations.RemoveField(
            model_name='packoptiontextes',
            name='packoption',
        ),
        migrations.RemoveField(
            model_name='packtexten',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packtextes',
            name='pack',
        ),
        migrations.DeleteModel(
            name='Pack',
        ),
        migrations.DeleteModel(
            name='PackImage',
        ),
        migrations.DeleteModel(
            name='PackImageTextEN',
        ),
        migrations.DeleteModel(
            name='PackImageTextES',
        ),
        migrations.DeleteModel(
            name='PackOption',
        ),
        migrations.DeleteModel(
            name='PackOptionTextEN',
        ),
        migrations.DeleteModel(
            name='PackOptionTextES',
        ),
        migrations.DeleteModel(
            name='PackTextEN',
        ),
        migrations.DeleteModel(
            name='PackTextES',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-31 07:54
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0005_remove_product_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='BrandTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.RemoveField(
            model_name='brand',
            name='name',
        ),
        migrations.RemoveField(
            model_name='brand',
            name='slug',
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='brandtexten',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Brand'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 08:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0011_groupvalueattribute_groupvaluefeature_groupvaluefeaturespecial_optionvalueattribute_optionvaluefeatu'),
    ]

    operations = [
        migrations.AddField(
            model_name='attribute',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.GroupValueAttribute', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='feature',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.GroupValueFeature', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='List value'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-17 10:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0021_subcategory_show_brand'),
    ]

    operations = [
        migrations.AddField(
            model_name='typetax',
            name='default',
            field=models.BooleanField(default=False, verbose_name='Default'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-28 08:50
from __future__ import unicode_literals

import codenerix.multiforms
import codenerix.views
import codenerix_products.views
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0009_brand_show_menu'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductImageCreate',
            fields=[
                ('productimage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='codenerix_products.ProductImage')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.views.GenProductImageUrl, 'codenerix_products.productimage', codenerix.multiforms.MultiForm, codenerix.views.GenCreate),
        ),
        migrations.CreateModel(
            name='ProductImageUpdate',
            fields=[
                ('productimage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='codenerix_products.ProductImage')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix_products.views.GenProductImageUrl, 'codenerix_products.productimage', codenerix.multiforms.MultiForm, codenerix.views.GenUpdate),
        ),
        migrations.AddField(
            model_name='attribute',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='brand',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='family',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='feature',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='flagshipproduct',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='productfinalimage',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='productimage',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.CreateModel(
            name='ProductImageCreateModal',
            fields=[
                ('productimagecreate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='codenerix_products.ProductImageCreate')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix.views.GenCreateModal, 'codenerix_products.productimagecreate'),
        ),
        migrations.CreateModel(
            name='ProductImageUpdateModal',
            fields=[
                ('productimageupdate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='codenerix_products.ProductImageUpdate')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix.views.GenUpdateModal, 'codenerix_products.productimageupdate'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-07 09:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0039_auto_20171103_1422'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='packing_cost',
            field=models.FloatField(blank=True, help_text='If it is empty, packing cost is equal to packing cost of product', null=True, verbose_name='Packing cost'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='weight',
            field=models.FloatField(blank=True, help_text='If it is empty, weight is equal to weight of product', null=True, verbose_name='Weight'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-08 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0040_auto_20171107_1013'),
    ]

    operations = [
        migrations.AddField(
            model_name='brandtexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaltexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaltextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='producttexttexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='producttexttextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='flagshipproduct',
            name='orientazion',
            field=models.CharField(choices=[('R', 'Right'), ('L', 'Left')], default='R', max_length=2, verbose_name='Orientazion'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 16:14
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0029_auto_20170803_1540'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductFinalOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('product_final', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='productfinals_option', to='codenerix_products.ProductFinal', verbose_name='Product Final')),
                ('products_pack', models.ManyToManyField(related_name='productfinals_optionpack', to='codenerix_products.ProductFinal')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('product_final_option', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.ProductFinalOption')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductFinalOptionTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('product_final_option', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.ProductFinalOption')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-07 10:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0003_auto_20170307_1027'),
    ]

    operations = [
        migrations.AlterField(
            model_name='productfeature',
            name='value',
            field=models.CharField(max_length=80, verbose_name='Value'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-02 09:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0023_pack_packoption_packoptiontexten_packoptiontextes_packtexten_packtextes'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pack',
            name='code',
            field=models.CharField(max_length=250, unique=True, verbose_name='Code'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-08 09:11
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0017_auto_20170505_1146'),
    ]

    operations = [
        migrations.DeleteModel(
            name='OptionValues',
        ),
        migrations.AlterModelOptions(
            name='optionvalueattribute',
            options={},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeature',
            options={},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturespecial',
            options={},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-10 12:36
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0041_auto_20171108_1628'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinaltexten',
            name='description_sample',
            field=codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description'),
        ),
        migrations.AddField(
            model_name='productfinaltextes',
            name='description_sample',
            field=codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Sample description'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 10:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0032_auto_20170904_1001'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='attribute',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='attributetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='attributetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='brandtexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='brandtextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='categorytexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='categorytextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='familytexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='familytextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='feature',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='featurespecial',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='featurespecialtexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='featurespecialtextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='featuretexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='featuretextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='flagshipproducttexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='flagshipproducttextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='groupvalueattribute',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='groupvaluefeature',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='groupvaluefeaturespecial',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvalueattribute',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvalueattributetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvalueattributetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeature',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturespecial',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturespecialtexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturespecialtextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='optionvaluefeaturetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='product',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productdocumenttexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productdocumenttextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinalimagetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinalimagetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinaloptiontexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinaloptiontextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinaltexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productfinaltextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productimagetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productimagetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productrelationsold',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='producttexttexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='producttexttextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='productunique',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='subcategorytexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='subcategorytextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 14:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0027_auto_20170803_1438'),
    ]

    operations = []



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-03 08:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='reviews_count',
            field=models.IntegerField(default=0, editable=False, verbose_name='Reviews count'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='reviews_value',
            field=models.FloatField(default=0, editable=False, verbose_name='Reviews'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:42
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0015_auto_20170505_1141'),
    ]

    operations = [
        migrations.RenameField(
            model_name='attribute',
            old_name='list_value_new',
            new_name='list_value',
        ),
        migrations.RenameField(
            model_name='feature',
            old_name='list_value_new',
            new_name='list_value',
        ),
        migrations.RenameField(
            model_name='featurespecial',
            old_name='list_value_new',
            new_name='list_value',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-04 08:01
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0031_auto_20170901_1256'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='typerecargoequivalencia',
            name='type_tax',
        ),
        migrations.DeleteModel(
            name='TypeRecargoEquivalencia',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-10-17 10:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0035_productfinal_sample'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='code',
            field=models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='price_base_local',
            field=models.FloatField(blank=True, null=True, verbose_name='Price base'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 10:34
from __future__ import unicode_literals

from django.db import migrations
from django.db import connection, transaction
from django.conf import settings

from codenerix_products.models import MODELS, \
    GroupValueAttribute, Attribute, OptionValueAttribute, \
    GroupValueFeature, Feature, OptionValueFeature, \
    GroupValueFeatureSpecial, FeatureSpecial, OptionValueFeatureSpecial

for info in MODELS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        cad = "from codenerix_products.models import {}Text{}\n".format(model, lang_code)
        exec(cad)


def migrate_group_value(model_group, table_source, model_option):
        model_str = str(model_option).replace('"', '').replace("'", '').replace(">", '').split(".")[-1]
        
        cursor = connection.cursor()
        # select all the groups related to the source table
        query = """
            SELECT cpa.id, cpa.list_value_id, cpg.name
            FROM {table} AS cpa, codenerix_products_groupvalue AS cpg
            WHERE cpa.list_value_id = cpg.id
        """.format(**{'table': table_source})
        cursor.execute(query)
        for src in cursor:
            if src[1]:
                group_id = src[1]
                group_name = src[2]

                # If the group does not exist, it is created
                group = model_group.objects.filter(name=group_name).first()
                if not group:
                    group = model_group()
                    group.name = src[2]
                    group.save()

                # List with language information
                text_lang = []
                # List with table names
                froms = ['codenerix_products_optionvalue cpo', ]
                # List of query conditions
                conditions = ['cpo.group_id = {}'.format(group_id), ]
                # List of values to get from the query
                values = []

                for lang_code in settings.LANGUAGES_DATABASES:
                    # We get the model according to language
                    model_lang = globals()["{}Text{}".format(model_str, lang_code)]
                    # We save the language information
                    # Language, table name in database and model
                    text_lang.append((lang_code, model_lang._meta.db_table, model_lang))

                    alias = "t{}".format(lang_code.lower())
                    values.append('{}.description'.format(alias))
                    froms.append('codenerix_products_optionvaluetext{lang} {alias}'.format(**{'lang': lang_code.lower(), 'alias': alias}))
                    conditions.append('{}.option_value_id = cpo.id'.format(alias))

                # We get the information of the option with the values in all their languages
                query_text = "SELECT {} FROM {} WHERE {}".format(",".join(values), ",".join(froms), " AND ".join(conditions))
                
                # Re-initialize the form list
                froms = ['codenerix_products_optionvalue cpo', ]
                # Initialize conditions again
                conditions = ['cpo.group_id = {}'.format(group_id), ]
                for tl in text_lang:
                    alias = "t{}".format(tl[0].lower())
                    table = tl[1]
                    # Name of the final table where the new options should be
                    froms.append('{} {}'.format(table, alias))
                    # Relationship between the language table and the options table
                    conditions.append('{}.option_value_id = cpo.id'.format(alias))
                
                cursor.execute(query_text)

                for option in cursor:
                    # List of new conditionals
                    cond_extra = []
                    for v, o in zip(values, option):
                        # Field name, description value
                        cond_extra.append('{} = "{}"'.format(v, o))

                    # We built the new query
                    q_option = "SELECT COUNT(*) FROM {} WHERE {} AND {}".format(
                        ",".join(froms),
                        " AND ".join(conditions),
                        " AND ".join(cond_extra)
                    )

                    cursor.execute(q_option)
                    count = cursor.fetchone()

                    if count[0] == 0:
                        opt = model_option()
                        opt.group = group
                        opt.save()

                        for info_lang, description in zip(text_lang, option):
                            model_lang = info_lang[2]
                            opt_lang = model_lang()
                            opt_lang.description = description
                            opt_lang.option_value = opt
                            opt_lang.save()
        return 0


def run_migrate(apps, schema_editor):
    migrate_group_value(GroupValueAttribute, 'codenerix_products_attribute', OptionValueAttribute)
    migrate_group_value(GroupValueFeature, 'codenerix_products_feature', OptionValueFeature)
    migrate_group_value(GroupValueFeatureSpecial, 'codenerix_products_featurespecial', OptionValueFeatureSpecial)


class Migration(migrations.Migration):
    dependencies = [
        ('codenerix_products', '0013_optionvalueattributetexten_optionvalueattributetextes_optionvaluefeaturespecialtexten_optionvaluefea'),
    ]

    operations = [
        migrations.RunPython(run_migrate),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:41
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0014_migrate_group_value'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='optionvaluetexten',
            name='option_value',
        ),
        migrations.RemoveField(
            model_name='optionvaluetextes',
            name='option_value',
        ),
        migrations.RemoveField(
            model_name='attribute',
            name='list_value',
        ),
        migrations.RemoveField(
            model_name='feature',
            name='list_value',
        ),
        migrations.RemoveField(
            model_name='featurespecial',
            name='list_value',
        ),
        migrations.DeleteModel(
            name='OptionValueTextEN',
        ),
        migrations.DeleteModel(
            name='OptionValueTextES',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0016_auto_20170505_1142'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='optionvalue',
            name='group',
        ),
        migrations.DeleteModel(
            name='GroupValue',
        ),
        migrations.DeleteModel(
            name='OptionValue',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-31 09:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0020_auto_20170523_0940'),
    ]

    operations = [
        migrations.AddField(
            model_name='subcategory',
            name='show_brand',
            field=models.BooleanField(default=True, verbose_name='Show brand (for menu)'),
        ),
    ]
